@@ -122,7 +122,7 @@ def dummy_keyring() -> DummyBackend:
 def with_simple_keyring(dummy_keyring: DummyBackend) -> None:
     import keyring
 
-    keyring.set_keyring(dummy_keyring)  # type: ignore[no-untyped-call]
+    keyring.set_keyring(dummy_keyring)
 
 
 @pytest.fixture()
@@ -476,3 +476,13 @@ def load_required_fixtures(
 ) -> None:
     for fixture in required_fixtures:
         fixture_copier(fixture)
+
+
+@pytest.fixture
+def venv_flags_default() -> dict[str, bool]:
+    return {
+        "always-copy": False,
+        "system-site-packages": False,
+        "no-pip": False,
+        "no-setuptools": False,
+    }
