@@ -420,7 +420,8 @@ def test_poetry_with_no_default_source(fixture_dir: FixtureDirGetter) -> None:
 def test_poetry_with_supplemental_source(
     fixture_dir: FixtureDirGetter, with_simple_keyring: None
 ) -> None:
-    poetry = Factory().create_poetry(fixture_dir("with_supplemental_source"))
+    io = BufferedIO()
+    poetry = Factory().create_poetry(fixture_dir("with_supplemental_source"), io=io)
 
     assert poetry.pool.has_repository("PyPI")
     assert poetry.pool.get_priority("PyPI") is Priority.DEFAULT
@@ -429,12 +430,14 @@ def test_poetry_with_supplemental_source(
     assert poetry.pool.get_priority("supplemental") is Priority.SUPPLEMENTAL
     assert isinstance(poetry.pool.repository("supplemental"), LegacyRepository)
     assert {repo.name for repo in poetry.pool.repositories} == {"PyPI", "supplemental"}
+    assert io.fetch_error() == ""
 
 
 def test_poetry_with_explicit_source(
     fixture_dir: FixtureDirGetter, with_simple_keyring: None
 ) -> None:
-    poetry = Factory().create_poetry(fixture_dir("with_explicit_source"))
+    io = BufferedIO()
+    poetry = Factory().create_poetry(fixture_dir("with_explicit_source"), io=io)
 
     assert len(poetry.pool.repositories) == 1
     assert len(poetry.pool.all_repositories) == 2
@@ -444,6 +447,7 @@ def test_poetry_with_explicit_source(
     assert poetry.pool.has_repository("explicit")
     assert isinstance(poetry.pool.repository("explicit"), LegacyRepository)
     assert {repo.name for repo in poetry.pool.repositories} == {"PyPI"}
+    assert io.fetch_error() == ""
 
 
 def test_poetry_with_explicit_pypi_and_other(
